==> haskell-hi-file-parser-0.1.7.0-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hi-file-parser
version:              0.1.7.0
visibility:           public
id:                   hi-file-parser-0.1.7.0-Gs1f7OEnbhvJYO7EbbJtHy
key:                  hi-file-parser-0.1.7.0-Gs1f7OEnbhvJYO7EbbJtHy
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Hussein Ait-Lahcen
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/hi-file-parser/blob/master/README.md>

category:             Development
abi:                  7c126dc3206717cc1681ef4fc3fb4bb1
exposed:              True
exposed-modules:      HiFileParser
hidden-modules:       Paths_hi_file_parser
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.7.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.7.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hi-file-parser
hs-libraries:         HShi-file-parser-0.1.7.0-Gs1f7OEnbhvJYO7EbbJtHy
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 mtl-2.2.2
    rio-0.1.22.0-JWvvEymNAMu3VyyPAfG55D text-2.0.2
    vector-0.13.2.0-B39FQf4cXUZ2GlwNF0TDTd

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hi-file-parser-0.1.7.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hi-file-parser
version:              0.1.7.0
visibility:           public
id:                   hi-file-parser-0.1.7.0-7qRAZsw6ocd9dzbAgRTC3O
key:                  hi-file-parser-0.1.7.0-7qRAZsw6ocd9dzbAgRTC3O
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Hussein Ait-Lahcen
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/hi-file-parser/blob/master/README.md>

category:             Development
abi:                  d884e2c110e950fe13b8e7bdbf95f7b6
exposed:              True
exposed-modules:      HiFileParser
hidden-modules:       Paths_hi_file_parser
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.7.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.7.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hi-file-parser-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hi-file-parser
hs-libraries:         HShi-file-parser-0.1.7.0-7qRAZsw6ocd9dzbAgRTC3O
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 mtl-2.2.2
    rio-0.1.22.0-Bg1L2h2DQaD9vqX7Il6wIS text-2.0.2
    vector-0.13.2.0-cop25r7TnE5vewvd3oOyK

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
